# NiemaBF
Niema's Python Bloom Filter implementation

## Installation
TreeSwift can be installed using `pip`:

```bash
sudo pip install niemabf
```

If you are using a machine on which you lack administrative powers, TreeSwift can be installed locally using `pip`:

```bash
pip install --user niemabf
```

## Usage
Example scripts are provided in the `example` folder. Full documentation can be found at: [https://niema.net/NiemaBF](https://niema.net/NiemaBF)
